@@ -52,6 +52,7 @@ module Linguist
     # Return true or false
     def generated?
       xcode_file? ||
+      intellij_file? ||
       cocoapods? ||
       carthage_build? ||
       generated_graphql_relay? ||
@@ -65,6 +66,7 @@ module Linguist
       poetry_lock? ||
       esy_lock? ||
       npm_shrinkwrap_or_package_lock? ||
+      terraform_lock? ||
       generated_yarn_plugnplay? ||
       godeps? ||
       generated_by_zephir? ||
@@ -78,11 +80,13 @@ module Linguist
       compiled_cython_file? ||
       pipenv_lock? ||
       generated_go? ||
+      generated_protocol_buffer_from_go? ||
       generated_protocol_buffer? ||
       generated_javascript_protocol_buffer? ||
       generated_apache_thrift? ||
       generated_jni_header? ||
       vcr_cassette? ||
+      generated_antlr? ||
       generated_module? ||
       generated_unity3d_meta? ||
       generated_racc? ||
@@ -111,6 +115,16 @@ module Linguist
     def xcode_file?
       ['.nib', '.xcworkspacedata', '.xcuserstate'].include?(extname)
     end
+    
+    # Internal: Is the blob an IntelliJ IDEA project file?
+    #
+    # JetBrains IDEs generate project files under an `.idea` directory
+    # that are sometimes checked into version control.
+    #
+    # Returns true or false.
+    def intellij_file?
+      !!name.match(/(?:^|\/)\.idea\//)
+    end
 
     # Internal: Is the blob part of Pods/, which contains dependencies not meant for humans in pull requests.
     #
@@ -308,6 +322,17 @@ module Linguist
       return lines.first(40).any? { |l| l.include? "Code generated by" }
     end
 
+    # Internal: Is the blob a protocol buffer file generated by the
+    # go-to-protobuf tool?
+    #
+    # Returns true or false
+    def generated_protocol_buffer_from_go?
+      return false unless extname == '.proto'
+      return false unless lines.count > 1
+
+      return lines.first(20).any? { |l| l.include? "This file was autogenerated by go-to-protobuf" }
+    end
+
     PROTOBUF_EXTENSIONS = ['.py', '.java', '.h', '.cc', '.cpp', '.m', '.rb', '.php']
 
     # Internal: Is the blob a C++, Java or Python source file generated by the
@@ -400,7 +425,7 @@ module Linguist
     #
     # Returns true or false.
     def generated_yarn_plugnplay?
-      !!name.match(/(^|\/)\.pnp\.(c|m)?js$/)
+      !!name.match(/(^|\/)\.pnp\..*$/)
     end
 
     # Internal: Is the blob part of Godeps/,
@@ -442,6 +467,15 @@ module Linguist
       return lines[-2].include?("recorded_with: VCR")
     end
 
+    # Is this a generated ANTLR file?
+    #
+    # Returns true or false
+    def generated_antlr?
+      return false unless extname == '.g'
+      return false unless lines.count > 2
+      return lines[1].include?("generated by Xtest")
+    end
+
     # Internal: Is this a compiled C/C++ file from Cython?
     #
     # Cython-compiled C/C++ files typically contain:
@@ -462,6 +496,13 @@ module Linguist
       !!name.match(/Pipfile\.lock/)
     end
 
+    # Internal: Is this a Terraform lock file?
+    #
+    # Returns true or false.
+    def terraform_lock?
+      !!name.match(/(?:^|\/)\.terraform\.lock\.hcl$/)
+    end
+
     # Internal: Is it a KiCAD or GFortran module file?
     #
     # KiCAD module files contain:
