@@ -161,9 +161,7 @@ module Linguist
 
           blob = Linguist::LazyBlob.new(repository, delta.new_file[:oid], new, mode.to_s(8))
 
-          if blob.include_in_language_stats?
-            file_map[new] = [blob.language.group.name, blob.size]
-          end
+          update_file_map(blob, file_map, new)
 
           blob.cleanup!
         end
@@ -171,5 +169,11 @@ module Linguist
 
       file_map
     end
+
+    def update_file_map(blob, file_map, key)
+      if blob.include_in_language_stats?
+        file_map[key] = [blob.language.group.name, blob.size]
+      end
+    end
   end
 end
